@@ -2,7 +2,7 @@ package AnyEvent::Twitter::Stream;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use AnyEvent;
 use AnyEvent::HTTP;
@@ -77,6 +77,10 @@ sub new {
             Scalar::Util::weaken($self);
 
             if ($handle) {
+                $handle->on_error(sub {
+                    undef $handle;
+                    $on_error->(@_);
+                });
                 $handle->on_eof(sub {
                     undef $handle;
                     $on_eof->(@_);
